@@ -1,3 +1,7 @@
+#if !defined (WOCKY_H_INSIDE) && !defined (WOCKY_COMPILATION)
+# error "Only <wocky/wocky.h> can be included directly."
+#endif
+
 #ifndef _WOCKY_JABBER_AUTH_DIGEST_H
 #define _WOCKY_JABBER_AUTH_DIGEST_H
 
@@ -31,12 +35,14 @@ typedef struct _WockyJabberAuthDigestPrivate WockyJabberAuthDigestPrivate;
 
 typedef struct
 {
+  /*<private>*/
   GObject parent;
   WockyJabberAuthDigestPrivate *priv;
 } WockyJabberAuthDigest;
 
 typedef struct
 {
+  /*<private>*/
   GObjectClass parent_class;
 } WockyJabberAuthDigestClass;
 
