@@ -1,9 +1,12 @@
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
 
 #include "wocky-jabber-auth-password.h"
 
 #include "wocky-auth-registry.h"
-#define DEBUG_FLAG DEBUG_AUTH
-#include "wocky-debug.h"
+#define WOCKY_DEBUG_FLAG WOCKY_DEBUG_AUTH
+#include "wocky-debug-internal.h"
 
 static void
 auth_handler_iface_init (gpointer g_iface);
