@@ -16,6 +16,9 @@
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
+#if !defined (WOCKY_H_INSIDE) && !defined (WOCKY_COMPILATION)
+# error "Only <wocky/wocky.h> can be included directly."
+#endif
 
 #ifndef __WOCKY_TYPES_H__
 #define __WOCKY_TYPES_H__
@@ -25,6 +28,7 @@
 G_BEGIN_DECLS
 
 typedef struct _WockyBareContact WockyBareContact;
+typedef struct _WockyLLContact WockyLLContact;
 typedef struct _WockyNodeTree WockyNodeTree;
 typedef struct _WockyResourceContact WockyResourceContact;
 typedef struct _WockySession WockySession;
