@@ -23,9 +23,7 @@
 #include "config.h"
 #include "gabble/caps-channel-manager.h"
 
-#include <telepathy-glib/dbus.h>
-#include <telepathy-glib/channel-manager.h>
-
+#include <telepathy-glib/telepathy-glib.h>
 
 #define DEBUG_FLAG GABBLE_DEBUG_PRESENCE
 #include "debug.h"
