@@ -35,13 +35,10 @@ void conn_olpc_activity_properties_init (GabbleConnection *conn);
 void conn_olpc_activity_properties_dispose (GabbleConnection *conn);
 
 gboolean conn_olpc_process_activity_properties_message (GabbleConnection *conn,
-    LmMessage *msg, const gchar *from);
+    WockyStanza *msg, const gchar *from);
 
 gboolean conn_olpc_process_activity_uninvite_message (GabbleConnection *conn,
-    LmMessage *msg, const gchar *from);
-
-LmHandlerResult conn_olpc_msg_cb (LmMessageHandler *handler,
-    LmConnection *connection, LmMessage *message, gpointer user_data);
+    WockyStanza *msg, const gchar *from);
 
 #endif /* __CONN_OLPC_H__ */
 
