@@ -25,8 +25,10 @@
 
 #include <dbus/dbus-protocol.h>
 #include <dbus/dbus-glib.h>
-#include <telepathy-glib/dbus.h>
-#include <telepathy-glib/errors.h>
+
+#include <telepathy-glib/telepathy-glib.h>
+#include <telepathy-glib/telepathy-glib-dbus.h>
+
 #include <wocky/wocky.h>
 
 #include "connection.h"
@@ -80,9 +82,7 @@ gabble_connection_manager_class_init (GabbleConnectionManagerClass *klass)
   TpBaseConnectionManagerClass *base_class =
     (TpBaseConnectionManagerClass *) klass;
 
-  base_class->new_connection = NULL;
   base_class->cm_dbus_name = "gabble";
-  base_class->protocol_params = NULL;
   object_class->constructed = gabble_connection_manager_constructed;
   object_class->finalize = gabble_connection_manager_finalize;
 }
