@@ -4,8 +4,7 @@
 #include "config.h"
 
 #include <glib.h>
-#include <wocky/wocky-stanza.h>
-#include <loudmouth/loudmouth.h>
+#include <wocky/wocky.h>
 
 G_BEGIN_DECLS
 
@@ -85,7 +84,7 @@ G_END_DECLS
 
 #   define NODE_DEBUG(n, s) \
     G_STMT_START { \
-      gchar *debug_tmp = lm_message_node_to_string (n); \
+      gchar *debug_tmp = wocky_node_to_string (n); \
       gabble_log (G_LOG_LEVEL_DEBUG, DEBUG_FLAG, "%s: %s:\n%s", G_STRFUNC, s, debug_tmp); \
       g_free (debug_tmp); \
     } G_STMT_END
@@ -110,7 +109,7 @@ STANZA_DEBUG (
 
 static inline void
 NODE_DEBUG (
-    LmMessageNode *node,
+    WockyNode *node,
     const gchar *format,
     ...)
 {
