@@ -21,10 +21,10 @@
 #define GABBLE_JINGLE_TP_UTIL_H
 
 #include <telepathy-glib/telepathy-glib.h>
-#include "jingle-content.h"
+#include <wocky/wocky.h>
 
-JingleMediaType jingle_media_type_from_tp (TpMediaStreamType type);
-TpMediaStreamType jingle_media_type_to_tp (JingleMediaType type);
+WockyJingleMediaType wocky_jingle_media_type_from_tp (TpMediaStreamType type);
+TpMediaStreamType wocky_jingle_media_type_to_tp (WockyJingleMediaType type);
 
 GPtrArray *gabble_build_tp_relay_info (GPtrArray *relays);
 
