@@ -22,8 +22,7 @@
 
 #include <glib-object.h>
 
-#include <telepathy-glib/enums.h>
-#include <telepathy-glib/handle-repo.h>
+#include <telepathy-glib/telepathy-glib.h>
 
 #include "connection.h"
 
