@@ -24,7 +24,7 @@
 
 #include <glib-object.h>
 
-#include <telepathy-glib/base-contact-list.h>
+#include <telepathy-glib/telepathy-glib.h>
 
 #include "types.h"
 
