@@ -3,6 +3,12 @@ from twisted.words.xish import domish
 import constants as cs
 from file_transfer_helper import exec_file_transfer_test, ReceiveFileTest
 
+from config import FILE_TRANSFER_ENABLED
+
+if not FILE_TRANSFER_ENABLED:
+    print "NOTE: built with --disable-file-transfer"
+    raise SystemExit(77)
+
 class ReceiveFileAndSenderDisconnectWhileTransfering(ReceiveFileTest):
     def accept_file(self):
         ReceiveFileTest.accept_file(self)
