@@ -1,6 +1,12 @@
 import constants as cs
 from file_transfer_helper import SendFileTest, exec_file_transfer_test
 
+from config import FILE_TRANSFER_ENABLED
+
+if not FILE_TRANSFER_ENABLED:
+    print "NOTE: built with --disable-file-transfer"
+    raise SystemExit(77)
+
 class SendFileAndCancelImmediatelyTest(SendFileTest):
     def provide_file(self):
         SendFileTest.provide_file(self)
