@@ -130,6 +130,7 @@ class JabberAuthenticator(GabbleAuthenticator):
     def streamStarted(self, root=None):
         if root:
             self.xmlstream.sid = '%x' % random.randint(1, sys.maxint)
+            self.xmlstream.domain = root.getAttribute('to')
 
         self.xmlstream.sendHeader()
         self.xmlstream.addOnetimeObserver(
@@ -175,7 +176,7 @@ class JabberAuthenticator(GabbleAuthenticator):
         if self.resource is not None:
             assertEquals(self.resource, str(resource[0]))
 
-        self.bare_jid = '%s@localhost' % self.username
+        self.bare_jid = '%s@%s' % (self.username, self.xmlstream.domain)
         self.full_jid = '%s/%s' % (self.bare_jid, resource)
 
         result = IQ(self.xmlstream, "result")
@@ -188,9 +189,12 @@ class XmppAuthenticator(GabbleAuthenticator):
         GabbleAuthenticator.__init__(self, username, password, resource)
         self.authenticated = False
 
+        self._mechanisms = ['PLAIN']
+
     def streamInitialize(self, root):
         if root:
             self.xmlstream.sid = root.getAttribute('id')
+            self.xmlstream.domain = root.getAttribute('to')
 
         if self.xmlstream.sid is None:
             self.xmlstream.sid = '%x' % random.randint(1, sys.maxint)
@@ -212,7 +216,8 @@ class XmppAuthenticator(GabbleAuthenticator):
     def streamSASL(self):
         features = domish.Element((xmlstream.NS_STREAMS, 'features'))
         mechanisms = features.addElement((ns.NS_XMPP_SASL, 'mechanisms'))
-        mechanism = mechanisms.addElement('mechanism', content='PLAIN')
+        for mechanism in self._mechanisms:
+            mechanisms.addElement('mechanism', content=mechanism)
         self.xmlstream.send(features)
 
         self.xmlstream.addOnetimeObserver("/auth", self.auth)
@@ -245,7 +250,7 @@ class XmppAuthenticator(GabbleAuthenticator):
         result = IQ(self.xmlstream, "result")
         result["id"] = iq["id"]
         bind = result.addElement((ns.NS_XMPP_BIND, 'bind'))
-        self.bare_jid = '%s@localhost' % self.username
+        self.bare_jid = '%s@%s' % (self.username, self.xmlstream.domain)
         self.full_jid = '%s/%s' % (self.bare_jid, resource)
         jid = bind.addElement('jid', content=self.full_jid)
         self.xmlstream.send(result)
@@ -397,6 +402,12 @@ class BaseXmlStream(xmlstream.XmlStream):
             self.addObserver("/iq/query[@xmlns='%s']" % ns.PRIVACY,
                              self._cb_priv_list)
 
+    def connectionMade(self):
+        xmlstream.XmlStream.connectionMade(self)
+
+        if 'GABBLE_NODELAY' in os.environ:
+            self.transport.setTcpNoDelay(True)
+
     def _cb_priv_list(self, iq):
         send_error_reply(self, iq)
 
@@ -406,7 +417,7 @@ class BaseXmlStream(xmlstream.XmlStream):
         assert self.authenticator.bare_jid is not None
 
         self.addObserver(
-            "/iq[@to='localhost']/query[@xmlns='http://jabber.org/protocol/disco#info']",
+            "/iq[@to='%s']/query[@xmlns='http://jabber.org/protocol/disco#info']" % self.domain,
             self._cb_disco_iq)
         self.addObserver(
             "/iq[@to='%s']/query[@xmlns='http://jabber.org/protocol/disco#info']"
@@ -446,6 +457,10 @@ class BaseXmlStream(xmlstream.XmlStream):
         # disconnect the TCP connection making tests as
         # connect/disconnect-timeout.py not working
 
+    def connectionLost(self, reason):
+        self.event_func(servicetest.Event('stream-connection-lost'))
+        xmlstream.XmlStream.connectionLost(self, reason)
+
     def send_stream_error(self, error='system-shutdown'):
         # Yes, there are meant to be two different STREAMS namespaces.
         go_away = \
@@ -540,17 +555,40 @@ def disconnect_conn(q, conn, stream, expected_before=[], expected_after=[]):
 
     return before_events[:-2], after_events[:-1]
 
+def element_repr(element):
+    """__repr__ cannot safely return non-ASCII: see
+    <http://bugs.python.org/issue5876>. So we print non-ASCII characters as
+    \uXXXX escapes in debug output
+
+    """
+    return element.toXml().encode('unicode-escape')
+
+def expect_connected(queue):
+    queue.expect('dbus-signal', signal='StatusChanged',
+        args=[cs.CONN_STATUS_CONNECTING, cs.CSR_REQUESTED])
+    queue.expect('stream-authenticated')
+    queue.expect('dbus-signal', signal='PresencesChanged',
+        args=[{1L: (cs.PRESENCE_AVAILABLE, u'available', '')}])
+    queue.expect('dbus-signal', signal='StatusChanged',
+        args=[cs.CONN_STATUS_CONNECTED, cs.CSR_REQUESTED])
+
 def exec_test_deferred(fun, params, protocol=None, timeout=None,
                         authenticator=None, num_instances=1,
-                        do_connect=True):
+                        do_connect=True,
+                        make_connection_func=make_connection,
+                        expect_connected_func=expect_connected):
     # hack to ease debugging
-    domish.Element.__repr__ = domish.Element.toXml
+    domish.Element.__repr__ = element_repr
     colourer = None
 
     if sys.stdout.isatty() or 'CHECK_FORCE_COLOR' in os.environ:
         colourer = servicetest.install_colourer()
 
-    bus = dbus.SessionBus()
+    try:
+        bus = dbus.SessionBus()
+    except dbus.exceptions.DBusException as e:
+        print e
+        os._exit(1)
 
     queue = servicetest.IteratingEventQueue(timeout)
     queue.verbose = (
@@ -568,7 +606,7 @@ def exec_test_deferred(fun, params, protocol=None, timeout=None,
             suffix = str(i)
 
         try:
-            (conn, jid) = make_connection(bus, queue.append, params, suffix)
+            (conn, jid) = make_connection_func(bus, queue.append, params, suffix)
         except Exception, e:
             # Crap. This is normally because the connection's still kicking
             # around on the bus. Let's bin any connections we *did* manage to
@@ -622,13 +660,7 @@ def exec_test_deferred(fun, params, protocol=None, timeout=None,
         if do_connect:
             for conn in conns:
                 conn.Connect()
-                queue.expect('dbus-signal', signal='StatusChanged',
-                    args=[cs.CONN_STATUS_CONNECTING, cs.CSR_REQUESTED])
-                queue.expect('stream-authenticated')
-                queue.expect('dbus-signal', signal='PresencesChanged',
-                    args=[{1L: (cs.PRESENCE_AVAILABLE, u'available', '')}])
-                queue.expect('dbus-signal', signal='StatusChanged',
-                    args=[cs.CONN_STATUS_CONNECTED, cs.CSR_REQUESTED])
+                expect_connected_func(queue)
 
         if len(conns) == 1:
             fun(queue, bus, conns[0], streams[0])
