@@ -92,7 +92,7 @@ def prepare_test(jp, q, bus, conn, stream):
                 cs.CALL_INITIAL_VIDEO: True},
             ], [
                 cs.CHANNEL_TYPE_CALL + '/gtalk-p2p',
-                cs.CHANNEL_TYPE_CALL + '/ice-udp',
+                cs.CHANNEL_TYPE_CALL + '/ice',
                 cs.CHANNEL_TYPE_CALL + '/video/h264',
             ]),
         ])
