@@ -7,11 +7,10 @@ from dbus.exceptions import DBusException
 
 from twisted.words.xish import xpath
 
-from gabbletest import exec_test, make_presence, sync_stream
+from gabbletest import exec_test, sync_stream
 from servicetest import (
-    make_channel_proxy, wrap_channel,
     EventPattern, call_async,
-    assertEquals, assertContains, assertLength, assertNotEquals
+    assertEquals, assertContains, assertLength
     )
 import constants as cs
 from jingletest2 import JingleTest2, test_all_dialects, JingleProtocol031
@@ -22,6 +21,12 @@ from mucutil import *
 
 from callutils import *
 
+from config import VOIP_ENABLED
+
+if not VOIP_ENABLED:
+    print "NOTE: built with --disable-voip"
+    raise SystemExit(77)
+
 muc = "muji@test"
 
 def run_incoming_test(q, bus, conn, stream, bob_leaves_room = False):
@@ -66,10 +71,9 @@ def run_incoming_test(q, bus, conn, stream, bob_leaves_room = False):
 
     check_state (q, channel, cs.CALL_STATE_PENDING_RECEIVER)
 
-    codecs = jt.get_call_audio_codecs_dbus()
-
-    check_and_accept_offer (q, bus, conn, self_handle, 0,
-            content, codecs)
+    md = jt.get_call_audio_md_dbus()
+    check_and_accept_offer (q, bus, conn, self_handle,
+            content, md)
     channel.Accept (dbus_interface=cs.CHANNEL_TYPE_CALL)
 
     # Preparing stanza
@@ -121,7 +125,7 @@ def run_incoming_test(q, bus, conn, stream, bob_leaves_room = False):
 
     q.unforbid_events (forbidden)
     content = bus.get_object (conn.bus_name, e.args[0])
-    check_and_accept_offer (q, bus, conn, self_handle, 0,
+    check_and_accept_offer (q, bus, conn, self_handle,
             content, jt.get_call_video_codecs_dbus(),
             check_codecs_changed = False)
 
@@ -185,13 +189,10 @@ def run_outgoing_test(q, bus, conn, stream, close_channel=False):
         dbus_interface = dbus.PROPERTIES_IFACE)
 
     content = bus.get_object (conn.bus_name, props['Contents'][0])
-    codecs = jt.get_call_audio_codecs_dbus()
 
-    # Accept codec offer
-    props = content.GetAll(cs.CALL_CONTENT_IFACE_MEDIA,
-        dbus_interface=dbus.PROPERTIES_IFACE)
-    offer = bus.get_object (conn.bus_name, props["CodecOffer"][0])
-    offer.Accept(codecs, dbus_interface=cs.CALL_CONTENT_CODECOFFER)
+
+    md = jt.get_call_audio_md_dbus()
+    check_and_accept_offer (q, bus, conn, content, md)
 
     # Accept the channel, which means we can get muji presences
     q.unforbid_events (forbidden)
@@ -226,9 +227,11 @@ def run_outgoing_test(q, bus, conn, stream, close_channel=False):
     # Bob appears and starts a session right afterwards
     q.expect('dbus-signal', signal = 'CallMembersChanged')
 
-    e = q.expect('dbus-signal', signal = 'NewCodecOffer')
-    offer = bus.get_object (conn.bus_name, e.args[1])
-    offer.Accept(codecs, dbus_interface=cs.CALL_CONTENT_CODECOFFER)
+    q.unforbid_events(forbidden)
+
+    e = q.expect('dbus-signal', signal = 'NewMediaDescriptionOffer')
+    offer = bus.get_object (conn.bus_name, e.args[0])
+    offer.Accept(md, dbus_interface=cs.CALL_CONTENT_MEDIADESCRIPTION)
 
     jt.incoming_call(audio = "Audio")
 
@@ -246,8 +249,10 @@ def run_outgoing_test(q, bus, conn, stream, close_channel=False):
 
     endpoint = bus.get_object (conn.bus_name, endpoints[0])
 
-    endpoint.SetStreamState (cs.MEDIA_STREAM_STATE_CONNECTED,
-        dbus_interface=cs.CALL_STREAM_ENDPOINT)
+    endpoint.SetEndpointState (1, cs.MEDIA_STREAM_STATE_CONNECTED,
+                               dbus_interface=cs.CALL_STREAM_ENDPOINT)
+    endpoint.SetEndpointState (2, cs.MEDIA_STREAM_STATE_CONNECTED,
+                               dbus_interface=cs.CALL_STREAM_ENDPOINT)
 
     e = q.expect ('stream-iq',
         predicate = jp.action_predicate ('session-accept'))
@@ -260,17 +265,13 @@ def run_outgoing_test(q, bus, conn, stream, close_channel=False):
     q.expect('dbus-signal', signal = 'ContentAdded')
 
     content = bus.get_object (conn.bus_name, c)
-    codecs = jt.get_call_video_codecs_dbus()
 
     # wait for the CodecOffer and Accept it
-    q.expect('dbus-signal', signal = 'NewCodecOffer')
-    props = content.GetAll(cs.CALL_CONTENT_IFACE_MEDIA,
-        dbus_interface=dbus.PROPERTIES_IFACE)
-    offer = bus.get_object (conn.bus_name, props["CodecOffer"][0])
-    offer.Accept(codecs, dbus_interface=cs.CALL_CONTENT_CODECOFFER)
-
-    q.unforbid_events(forbidden)
+    q.expect('dbus-signal', signal = 'NewMediaDescriptionOffer')
 
+    md = jt.get_call_video_md_dbus()
+    check_and_accept_offer (q, bus, conn, content, md)
+    
     # preparing
     e = q.expect('stream-presence', to = muc + "/test")
     echo_muc_presence (q, stream, e.stanza, 'none', 'participant')
@@ -293,8 +294,8 @@ def run_outgoing_test(q, bus, conn, stream, close_channel=False):
     stream.send(presence)
 
     # new codec offer as bob threw in some codecs
-    q.expect('dbus-signal', signal='NewCodecOffer')
-    check_and_accept_offer (q, bus, conn, self_handle, 0,
+    q.expect('dbus-signal', signal='NewMediaDescriptionOffer')
+    check_and_accept_offer (q, bus, conn, self_handle,
             content, codecs, check_codecs_changed = False)
 
     # Bob sends a content
@@ -353,6 +354,9 @@ def general_tests (jp, q, bus, conn, stream, path, props):
     assertLength(1, contents)
 
 if __name__ == '__main__':
+    print "FIXME: needs to be ported to Call1"
+    raise SystemExit(77)
+
     exec_test (run_outgoing_test)
     exec_test (lambda q,b, c, s: run_outgoing_test (q, b, c, s, True))
     exec_test (run_incoming_test)
