@@ -6,21 +6,16 @@ test OLPC Buddy properties change notifications
 from servicetest import EventPattern
 from gabbletest import exec_test, acknowledge_iq
 import constants as cs
-from util import announce_gadget, send_buddy_changed_properties_msg
+from util import send_buddy_changed_properties_msg
 import ns
 
 def test(q, bus, conn, stream):
-    conn.Connect()
-
-    _, iq_event, disco_event = q.expect_many(
-        EventPattern('dbus-signal', signal='StatusChanged',
-            args=[cs.CONN_STATUS_CONNECTED, cs.CSR_REQUESTED]),
+    iq_event, disco_event = q.expect_many(
         EventPattern('stream-iq', to=None, query_ns='vcard-temp',
             query_name='vCard'),
         EventPattern('stream-iq', to='localhost', query_ns=ns.DISCO_ITEMS))
 
     acknowledge_iq(stream, iq_event.stanza)
-    announce_gadget(q, stream, disco_event.stanza)
 
     handles = {}
 
