@@ -9,7 +9,8 @@ from gabbletest import exec_test
 from servicetest import EventPattern, assertEquals, assertNotEquals
 import ns
 import constants as cs
-from invisible_helper import ValidInvisibleListStream, Xep0186XmlStream
+from invisible_helper import ValidInvisibleListStream, Xep0186Stream, \
+    Xep0186AndValidInvisibleListStream
 
 def test(q, bus, conn, stream):
     props = conn.Properties.GetAll(cs.CONN_IFACE_SIMPLE_PRESENCE)
@@ -30,6 +31,7 @@ def test(q, bus, conn, stream):
     assertEquals('watching bees', children[1].children[0])
 
 if __name__ == '__main__':
-    exec_test(test)
-    exec_test(test, protocol=ValidInvisibleListStream)
-    exec_test(test, protocol=Xep0186XmlStream)
+    exec_test(test, do_connect=False)
+    for protocol in [ValidInvisibleListStream, Xep0186Stream,
+                     Xep0186AndValidInvisibleListStream]:
+        exec_test(test, protocol=protocol, do_connect=False)
